#!/usr/bin/env python

'''
'''

from distutils.core import setup

setup(name='euclid',
      version='1.0',
      description='2D and 3D vector, matrix, quaternion and geometry module',
      author='Alex Holkner',
      author_email='alex@partiallydisassembled.net',
      maintainer='Richard Jones',
      maintainer_email='r1chardj0n3s@gmail.com',
      url='https://github.com/r1chardj0n3s/euclid',
      py_modules=['euclid'],
      )

